==> udunits-4.5.5-sources.jar: ucar/units/PrefixDB.java <==
/*
 * Copyright 1998-2014 University Corporation for Atmospheric Research/Unidata
 *
 *   Portions of this software were developed by the Unidata Program at the
 *   University Corporation for Atmospheric Research.
 *
 *   Access and use of this software shall impose the following obligations
 *   and understandings on the user. The user is granted the right, without
 *   any fee or cost, to use, copy, modify, alter, enhance and distribute
 *   this software, and any derivative works thereof, and its supporting
 *   documentation for any purpose whatsoever, provided that this entire
 *   notice appears in all copies of the software, derivative works and
 *   supporting documentation.  Further, UCAR requests that the user credit
 *   UCAR/Unidata in any publications that result from the use of this
 *   software or in any product that includes this software. The names UCAR
 *   and/or Unidata, however, may not be used in any advertising or publicity
 *   to endorse or promote any products or commercial entity unless specific
 *   written permission is obtained from UCAR/Unidata. The user also
 *   understands that UCAR/Unidata is not obligated to provide the user with
 *   any support, consulting, training or assistance of any kind with regard
 *   to the use, operation and performance of this software nor to provide
 *   the user with any updates, revisions, new versions or "bug fixes."
 *
 *   THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 *   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 *   INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 *   FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 *   NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 *   WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
package ucar.units;

import java.util.Iterator;

/**
 * Interface for a database of unit prefixes.
 * 
 * @author Steven R. Emmerson
 */
public interface PrefixDB {
	/**
	 * Adds a prefix to the database by name.
	 * 
	 * @param name
	 *            The name of the prefix.
	 * @param value
	 *            The value of the prefix.
	 * @throws PrefixExistsException
	 *             A prefix with the same name already exists in the database.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
	public void addName(String name, double value)
			throws PrefixExistsException, PrefixDBAccessException;

	/**
	 * Adds a prefix to the database by symbol.
	 * 
	 * @param symbol
	 *            The symbol for the prefix.
	 * @param value
	 *            The value of the prefix.
	 * @throws PrefixExistsException
	 *             A prefix with the same symbol already exists in the database.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
	public void addSymbol(String symbol, double value)
			throws PrefixExistsException, PrefixDBAccessException;

	/**
	 * Gets a prefix from the database by name.
	 * 
	 * @param name
	 *            The name of the prefix.
	 * @return prefix The prefix or null.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
	public Prefix getPrefixByName(String name) throws PrefixDBAccessException;

	/**
	 * Gets a prefix from the database by symbol.
	 * 
	 * @param symbol
	 *            The symbol for the prefix.
	 * @return prefix The prefix or null.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
	public Prefix getPrefixBySymbol(String symbol)
			throws PrefixDBAccessException;

	/**
	 * Gets a prefix from the database by value.
	 * 
	 * @param value
	 *            The value for the prefix.
	 * @return prefix The prefix or null.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
	public Prefix getPrefixByValue(double value) throws PrefixDBAccessException;

	/**
	 * Gets a string representation of this database.
	 * 
	 * @return A string representation of this database.
	 */
	public String toString();

	/**
	 * Gets an iterator over the entries in the database.
	 * 
	 * @return An iterator over the database.
	 */
	public Iterator<?> iterator();
}

==> udunits-5.0.0-20190723.062648-361-sources.jar: ucar/units/PrefixDB.java <==
/*
 * Copyright (c) 1998-2018 University Corporation for Atmospheric Research/Unidata
 * See LICENSE for license information.
 */
package ucar.units;

import java.util.Iterator;

/**
 * Interface for a database of unit prefixes.
 * 
 * @author Steven R. Emmerson
 */
public interface PrefixDB {
	/**
	 * Adds a prefix to the database by name.
	 * 
	 * @param name
	 *            The name of the prefix.
	 * @param value
	 *            The value of the prefix.
	 * @throws PrefixExistsException
	 *             A prefix with the same name already exists in the database.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
  void addName(String name, double value)
			throws PrefixExistsException, PrefixDBAccessException;

	/**
	 * Adds a prefix to the database by symbol.
	 * 
	 * @param symbol
	 *            The symbol for the prefix.
	 * @param value
	 *            The value of the prefix.
	 * @throws PrefixExistsException
	 *             A prefix with the same symbol already exists in the database.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
  void addSymbol(String symbol, double value)
			throws PrefixExistsException, PrefixDBAccessException;

	/**
	 * Gets a prefix from the database by name.
	 * 
	 * @param name
	 *            The name of the prefix.
	 * @return prefix The prefix or null.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
  Prefix getPrefixByName(String name) throws PrefixDBAccessException;

	/**
	 * Gets a prefix from the database by symbol.
	 * 
	 * @param symbol
	 *            The symbol for the prefix.
	 * @return prefix The prefix or null.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
  Prefix getPrefixBySymbol(String symbol)
			throws PrefixDBAccessException;

	/**
	 * Gets a prefix from the database by value.
	 * 
	 * @param value
	 *            The value for the prefix.
	 * @return prefix The prefix or null.
	 * @throws PrefixDBAccessException
	 *             Prefix database access failure.
	 */
  Prefix getPrefixByValue(double value) throws PrefixDBAccessException;

	/**
	 * Gets a string representation of this database.
	 * 
	 * @return A string representation of this database.
	 */
  String toString();

	/**
	 * Gets an iterator over the entries in the database.
	 * 
	 * @return An iterator over the database.
	 */
  Iterator<?> iterator();
}
